==> fo_components-0.0.1375.tar.gz: lib/components/fo_time_picker_component/fo_time_picker_component.dart <==
// Copyright (c) 2017, Patrick Minogue. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'dart:async' show Stream, StreamController;
import 'dart:math';
import 'package:angular2/angular2.dart';
import 'package:fo_components/components/icon_component/icon_component.dart';

@Component(
    selector: 'fo-time-picker',
    styleUrls: const ['fo_time_picker_component.css'],
    templateUrl: 'fo_time_picker_component.html',
    preserveWhitespace: false,
    directives: const [IconComponent],
    changeDetection: ChangeDetectionStrategy.OnPush)

class FoTimePickerComponent implements OnDestroy
{
  FoTimePickerComponent();

  void ngOnDestroy()
  {
    _onTimeChangeController.close();
  }

  String calcHourLeft(String hour)
  {
    int degrees = 30 * int.parse(hour) - 90;
    double left = 40 * cos(degrees.toDouble() * (PI / 180)) + 50;
    return "${left}%";
  }

  String calcHourTop(String hour)
  {
    int degrees = 30 * int.parse(hour) - 90;
    double top = 40 * sin(degrees.toDouble() * (PI / 180)) + 50;
    return "${top}%";
  }

  String calcMinuteLeft(String minute)
  {
    int degrees = (6 * int.parse(minute) - 90);
    double left = 40 * cos(degrees.toDouble() * (PI / 180)) + 50;
    return "${left}%";
  }

  String calcMinuteTop(String minute)
  {
    int degrees = (6 * int.parse(minute) - 90);
    double top = 40 * sin(degrees.toDouble() * (PI / 180)) + 50;
    return "${top}%";
  }

  bool get amMode => _amMode;
  String get strHour => _strHour;
  String get strMinute => _strMinute;

  void set amMode(bool value)
  {
    _amMode = value;
    _evalAmPm();


    _onTimeChangeController.add((strHour == null || strMinute == null) ? null : "$_strHour:$_strMinute");
  }

  void set strHour(String value)
  {
    _strHour = value;
    _evalAmPm();
  }

  void set strMinute(String value)
  {
    _strMinute = value;
    _evalAmPm();

    _onTimeChangeController.add((strHour == null || strMinute == null) ? null : "$_strHour:$_strMinute");
  }

  void _evalAmPm()
  {
    if (_strHour != null)
    {
      int hourIndex = int.parse(_strHour);
      if (hourIndex >= 12) hourIndex -= 12;
      _strHour = (_amMode) ? hours[hourIndex] : hoursAfterLunch[hourIndex];
    }
  }

  final StreamController<String> _onTimeChangeController = new StreamController();
  final List<String> hours = ["12","01","02","03","04","05","06","07","08","09","10","11"];
  final List<String> hoursAfterLunch = ["12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23"];
  final List<String> minutes = ["00","05","10","15","20","25","30","35","40","45","50","55"];
  String _strHour;
  String _strMinute;
  bool _amMode = false;

  @Input('time')
  void set time(String value)
  {
    if (value == null)
    {
      _strMinute = null;
      _strHour = null;
    }
    else
    {
      RegExp r = new RegExp(r"[0-9]{2}:[0-9]{2}");
      String strMatch = r.stringMatch(value);

      if (strMatch == null || strMatch.compareTo(value) != 0) throw new FormatException("Invalid time format (must be HH:MM)");

      List<String> split = value.split(":");
      _strHour = split.first;
      _strMinute = split.last;
    }
  }

  @Output('timeChange')
  Stream<String> get onTimeChangeOutput => _onTimeChangeController.stream;
}

==> fo_components-0.0.1376.tar.gz: lib/components/fo_time_picker_component/fo_time_picker_component.dart <==
// Copyright (c) 2017, Patrick Minogue. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'dart:async' show Stream, StreamController;
import 'dart:math';
import 'package:angular2/angular2.dart';
import 'package:fo_components/components/icon_component/icon_component.dart';

@Component(
    selector: 'fo-time-picker',
    styleUrls: const ['fo_time_picker_component.css'],
    templateUrl: 'fo_time_picker_component.html',
    preserveWhitespace: false,
    directives: const [IconComponent],
    changeDetection: ChangeDetectionStrategy.OnPush)

class FoTimePickerComponent implements OnDestroy, AfterContentInit
{
  FoTimePickerComponent();

  void ngOnDestroy()
  {
    _onTimeChangeController.close();
  }

  void ngAfterContentInit()
  {
    print("CONTENT INIT");

  }

  String calcHourLeft(String hour)
  {
    int degrees = 30 * int.parse(hour) - 90;
    double left = 40 * cos(degrees.toDouble() * (PI / 180)) + 50;
    return "${left}%";
  }

  String calcHourTop(String hour)
  {
    int degrees = 30 * int.parse(hour) - 90;
    double top = 40 * sin(degrees.toDouble() * (PI / 180)) + 50;
    return "${top}%";
  }

  String calcMinuteLeft(String minute)
  {
    int degrees = (6 * int.parse(minute) - 90);
    double left = 40 * cos(degrees.toDouble() * (PI / 180)) + 50;
    return "${left}%";
  }

  String calcMinuteTop(String minute)
  {
    int degrees = (6 * int.parse(minute) - 90);
    double top = 40 * sin(degrees.toDouble() * (PI / 180)) + 50;
    return "${top}%";
  }

  bool get amMode => _amMode;
  String get strHour => _strHour;
  String get strMinute => _strMinute;

  void set amMode(bool value)
  {
    _amMode = value;
    _evalAmPm();


    _onTimeChangeController.add((strHour == null || strMinute == null) ? null : "$_strHour:$_strMinute");
  }

  void set strHour(String value)
  {
    _strHour = value;
    _evalAmPm();
  }

  void set strMinute(String value)
  {
    _strMinute = value;
    _evalAmPm();

    _onTimeChangeController.add((strHour == null || strMinute == null) ? null : "$_strHour:$_strMinute");
  }

  void _evalAmPm()
  {
    if (_strHour != null)
    {
      int hourIndex = int.parse(_strHour);
      if (hourIndex >= 12) hourIndex -= 12;
      _strHour = (_amMode) ? hours[hourIndex] : hoursAfterLunch[hourIndex];
    }
  }

  final StreamController<String> _onTimeChangeController = new StreamController();
  final List<String> hours = ["12","01","02","03","04","05","06","07","08","09","10","11"];
  final List<String> hoursAfterLunch = ["12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23"];
  final List<String> minutes = ["00","05","10","15","20","25","30","35","40","45","50","55"];
  String _strHour;
  String _strMinute;
  bool _amMode = false;

  @Input('time')
  void set time(String value)
  {
    if (value == null)
    {
      _strMinute = null;
      _strHour = null;
    }
    else
    {
      RegExp r = new RegExp(r"[0-9]{2}:[0-9]{2}");
      String strMatch = r.stringMatch(value);

      if (strMatch == null || strMatch.compareTo(value) != 0) throw new FormatException("Invalid time format (must be HH:MM)");

      List<String> split = value.split(":");
      _strHour = split.first;
      _strMinute = split.last;
    }
  }

  @Output('timeChange')
  Stream<String> get onTimeChangeOutput => _onTimeChangeController.stream;
}
